Funding
=======
The following institutions, missions, and programs have provided funding
for pysatMissions development.

Institutions
------------
 - The Catholic University of America (CUA)
 - Cosmic Studio
 - National Aeronautics and Space Administration (NASA)
 - National Science Foundation (NSF)
 - Office of Naval Research (ONR)
 - Universities Space Research Association
 - The University of Texas at Dallas

Programs
--------
 - NSF 125908, AGS-1651393
 - Naval Research Laboratory N00173191G016 and N0017322P0744
 - The Space Precipitation Impacts (SPI) project at Goddard Space Flight Center
   through the Heliophysics Internal Science Funding Model

Disclaimers
===========
Any opinions or actions taken by the listed funding institutions are those of
the institutions and do not necessarily reflect the views of the pysatMissions
development team or individual authors. Any opinions, findings, and conclusions
or recommendations expressed in this material are those of the author(s) and do
not necessarily reflect the views of the funding agencies.
